==> ltsp-cluster-control_2.0.0.orig.tar.gz: ltsp-cluster-control-2.0.0/Admin/util/nodesBrowserView.php <==
<?php
/*
# Copyright 2004, Revolution Linux Inc., Nicolas Dufresne
#
# This file is part of the MILLE-XTERM distribution.
# See the MILLE-XTERM (english) and/or the MILLE (french) project web site
#
# http://www.revolutionlinux.com/mille-xterm/
# http://www.mille.ca/
#
# The MILLE-XTERM framework is covered by the GNU General Public License. See
# the COPYING file in the top-level MILLE-XTERM directory. Software packages
# that are included in the MILLE-XTERM distribution have their own licenses.
#
# -------------------------------------------------------------------------
*/
?>
<h3><?= getMessage('config_select_tree') ?></h3>
<form  name="finder" action="admin.php?<?= getGETParam() ?>" method="POST">
	<p>
	<?= getMessage('id_or_mac') ?>
	<input type="TEXT" name="<?= $this->nb_find?>" value="<? if( isset( $_POST[$this->nb_find] ) ) echo trim($_POST[$this->nb_find]); ?>">
	<input type="SUBMIT" value="<?= getMEssage('find') ?>"><br>
	<?php $this->printErrors(); ?>
	</p>
</form>
<?php
    if($termonly && $this->type == COMPUTER_TYPE && $this->node->mac=="00:00:00:00:00:00") {
        echo getMessage("noaccess");
        exit;
    }
?>
<form  name="finder" action="admin.php?<?= getGETParam() ?>" method="GET">
	<p>
<?php
	if(is_array($this->parents)) {
		$currend_node_id = $_GET[$this->node_id];
		foreach ($this->parents as $parent) {
			$_GET[$this->node_id] = $parent->getID();
			if (!($termonly && $this->type == COMPUTER_TYPE)) echo "<a href=\"admin.php?".getGETParam()."\">";
			echo "[".$parent->getName()."]";
			if (!($termonly && $this->type == COMPUTER_TYPE)) echo "</a>";
			echo " ";
		}
		$_GET[$this->node_id] = $currend_node_id;
	}
?>
	<font color="#ff0000" >[
<?php
	if ($this->node->isNode())
		print $this->node->getName();
	else if ($this->node->nodetype == COMPUTER_TYPE)
		print $this->node->getMac();
	else if ($this->node->nodetype == HWGROUP_TYPE)
		print $this->node->getName();
?>
	] </font>
<?php
	if ($this->type == NODE_TYPE) {
	    $isEmpty = true;
	    if (is_array($this->childrens)) {
		foreach ($this->childrens as $child) {
		    if ($child->isNode()) {
			$isEmpty = false;
			break;
		    }
		}
	    }
	    if ($isEmpty) {
		$this->childrens = NULL;
	    }
	}
	if($this->node->isNode() && is_array($this->childrens)) {

?>
	<select name="<?= $this->node_id ?>">

<?php
		if(is_array($this->childrens) && $this->hasPermission) {
		    if ($this->type == COMPUTER_TYPE) {
?>
		<optgroup label="<?= getMessage('node') ?>">
<?php
		    }
		    foreach ($this->childrens as $child) {
			if ($child->isNode()) {
?>
			<option value="<?= $child->getID() ?>"><?= $child->getName() ?></option>
<?php
				}
			}
		}
		if(is_array($this->childrens)&& $this->hasPermission) {
		    if ($this->type == COMPUTER_TYPE) {
?>
		<optgroup label="<?= getMessage('computer') ?>">
<?php
			foreach ($this->childrens as $child) {
			    if ($child->nodetype==COMPUTER_TYPE) {
?>
			<option value="<?= $child->getID() ?>"><?= $child->getMac() ?></option>
<?php
			    }
			}
		    }
		}
		if(is_array($this->childrens)&& $this->hasPermission) {
		    if ($this->type == COMPUTER_TYPE) {
?>
		<optgroup label="<?= getMessage('hardware_group') ?>">
<?php
			foreach ($this->childrens as $child) {
			    if ($child->nodetype==HWGROUP_TYPE) {
?>
			<option value="<?= $child->getID() ?>"><?= $child->getName() ?></option>
<?php
			    }
			}
		    }
		}
?>
	</select>
	<input type="SUBMIT" value="<?= getMessage('go') ?>">
<?php
	}
	foreach ($_GET as $name => $value) {
		if ($name != $this->node_id) {
?>
	<input type="HIDDEN" name="<?= $name ?>" value="<?= $value ?>">
<?php
		}
	}
?>
	</p>
</form>

==> ltsp-cluster-control_2.0.2.orig.tar.gz: ltsp-cluster-control-2.0.2/Admin/util/nodesBrowserView.php <==
<?php
/*
# Copyright 2004, Revolution Linux Inc., Nicolas Dufresne
#
# This file is part of the MILLE-XTERM distribution.
# See the MILLE-XTERM (english) and/or the MILLE (french) project web site
#
# http://www.revolutionlinux.com/mille-xterm/
# http://www.mille.ca/
#
# The MILLE-XTERM framework is covered by the GNU General Public License. See
# the COPYING file in the top-level MILLE-XTERM directory. Software packages
# that are included in the MILLE-XTERM distribution have their own licenses.
#
# -------------------------------------------------------------------------
*/
?>
<h3><?= getMessage('config_select_tree') ?></h3>
<form  name="finder" action="admin.php?<?= getGETParam() ?>" method="POST">
	<p>
	<?= getMessage('id_or_mac') ?>
	<input type="TEXT" name="<?= $this->nb_find?>" value="<? if( isset( $_POST[$this->nb_find] ) ) echo trim($_POST[$this->nb_find]); ?>">
	<input type="SUBMIT" value="<?= getMEssage('find') ?>"><br>
	<?php $this->printErrors(); ?>
	</p>
</form>
                <form method='get' action='/ltsp-cluster-control/Admin/inventory.php'>
                    <?= getMessage('search_inv') ?> <input type='text' name='number'/><input type='submit' value="<?= getMEssage('find') ?>"/>
                </form>
<?php
    if($termonly && $this->type == COMPUTER_TYPE && $this->node->mac=="00:00:00:00:00:00") {
        echo getMessage("noaccess");
        exit;
    }
?>
<form  name="finder" action="admin.php?<?= getGETParam() ?>" method="GET">
	<p>
<?php
	if(is_array($this->parents)) {
		$currend_node_id = $_GET[$this->node_id];
		foreach ($this->parents as $parent) {
			$_GET[$this->node_id] = $parent->getID();
			if (!($termonly && $this->type == COMPUTER_TYPE)) echo "<a href=\"admin.php?".getGETParam()."\">";
			echo "[".$parent->getName()."]";
			if (!($termonly && $this->type == COMPUTER_TYPE)) echo "</a>";
			echo " ";
		}
		$_GET[$this->node_id] = $currend_node_id;
	}
?>
	<font color="#ff0000" >[
<?php
	if ($this->node->isNode())
		print $this->node->getName();
	else if ($this->node->nodetype == COMPUTER_TYPE)
		print $this->node->getMac();
	else if ($this->node->nodetype == HWGROUP_TYPE)
		print $this->node->getName();
?>
	] </font>
<?php
	if ($this->type == NODE_TYPE) {
	    $isEmpty = true;
	    if (is_array($this->childrens)) {
		foreach ($this->childrens as $child) {
		    if ($child->isNode()) {
			$isEmpty = false;
			break;
		    }
		}
	    }
	    if ($isEmpty) {
		$this->childrens = NULL;
	    }
	}
	if($this->node->isNode() && is_array($this->childrens)) {

?>
	<select name="<?= $this->node_id ?>">

<?php
		if(is_array($this->childrens) && $this->hasPermission) {
		    if ($this->type == COMPUTER_TYPE) {
?>
		<optgroup label="<?= getMessage('node') ?>">
<?php
		    }
		    foreach ($this->childrens as $child) {
			if ($child->isNode()) {
?>
			<option value="<?= $child->getID() ?>"><?= $child->getName() ?></option>
<?php
				}
			}
		}
		if(is_array($this->childrens)&& $this->hasPermission) {
		    if ($this->type == COMPUTER_TYPE) {
?>
		<optgroup label="<?= getMessage('computer') ?>">
<?php
			foreach ($this->childrens as $child) {
			    if ($child->nodetype==COMPUTER_TYPE) {
?>
			<option value="<?= $child->getID() ?>"><?= $child->getMac() ?></option>
<?php
			    }
			}
		    }
		}
		if(is_array($this->childrens)&& $this->hasPermission) {
		    if ($this->type == COMPUTER_TYPE) {
?>
		<optgroup label="<?= getMessage('hardware_group') ?>">
<?php
			foreach ($this->childrens as $child) {
			    if ($child->nodetype==HWGROUP_TYPE) {
?>
			<option value="<?= $child->getID() ?>"><?= $child->getName() ?></option>
<?php
			    }
			}
		    }
		}
?>
	</select>
	<input type="SUBMIT" value="<?= getMessage('go') ?>">
<?php
	}
	foreach ($_GET as $name => $value) {
		if ($name != $this->node_id) {
?>
	<input type="HIDDEN" name="<?= $name ?>" value="<?= $value ?>">
<?php
		}
	}
?>
	</p>
</form>
